@@ -73,7 +73,33 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
         total_frames_processed = getattr(self, '_total_frames_processed', 0)
         global_frame_offset = getattr(self, 'global_frame_offset', 0)
 
-        for frame_id, detections in processed_data.items():
+        # Try to get FPS from stream_info or config
+        fps = None
+        if stream_info:
+            fps = stream_info.get('fps') or stream_info.get('frame_rate')
+        if not fps:
+            fps = getattr(config, 'fps', None) or getattr(config, 'frame_rate', None)
+        try:
+            fps = float(fps)
+            if fps <= 0:
+                fps = None
+        except Exception:
+            fps = None
+
+        # If frame_ids are not sorted, sort them numerically if possible
+        try:
+            frame_ids = sorted(processed_data.keys(), key=lambda x: int(x))
+        except Exception:
+            frame_ids = list(processed_data.keys())
+
+
+        # For real-time fallback, record wall-clock start time
+        wallclock_start_time = None
+        if not fps:
+            wallclock_start_time = time.time()
+
+        for idx, frame_id in enumerate(frame_ids):
+            detections = processed_data[frame_id]
             staff_count = sum(1 for d in detections if d.get('category') == 'staff')
             customer_count = sum(1 for d in detections if d.get('category') == 'customer')
             total_people = staff_count + customer_count
@@ -84,7 +110,41 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
             journey_analytics = analytics_results.get("customer_journey_analytics", {})
             business_metrics = analytics_results.get("business_metrics", {})
 
-            current_timestamp = self._get_current_timestamp_str(stream_info)
+            # --- Per-frame timestamp logic ---
+            # 1. Try to get from stream_info (video_timestamp)
+            # 2. Else, estimate from frame index and FPS
+            # 3. Else, use real wall-clock elapsed time
+            current_timestamp = None
+            if stream_info:
+                input_settings = stream_info.get("input_settings", {})
+                stream_type = input_settings.get("stream_type", "video_file")
+                if stream_type == "video_file":
+                    # If video_timestamp is a list, use per-frame
+                    video_timestamps = stream_info.get("video_timestamp")
+                    if isinstance(video_timestamps, list) and len(video_timestamps) > idx:
+                        current_timestamp = video_timestamps[idx][:8]
+                    elif isinstance(video_timestamps, str):
+                        current_timestamp = video_timestamps[:8]
+                elif stream_type == "stream":
+                    stream_times = stream_info.get("stream_time")
+                    if isinstance(stream_times, list) and len(stream_times) > idx:
+                        current_timestamp = stream_times[idx][:8]
+                    elif isinstance(stream_times, str):
+                        current_timestamp = stream_times[:8]
+            # If still not found, estimate from frame index and FPS
+            if not current_timestamp or current_timestamp == "00:00:00.00":
+                if fps:
+                    total_seconds = idx / fps
+                elif wallclock_start_time is not None:
+                    total_seconds = time.time() - wallclock_start_time
+                else:
+                    total_seconds = 0
+                hours = int(total_seconds // 3600)
+                minutes = int((total_seconds % 3600) // 60)
+                seconds = int(total_seconds % 60)
+                centiseconds = int((total_seconds - int(total_seconds)) * 100)
+                current_timestamp = f"{hours:02d}:{minutes:02d}:{seconds:02d}.{centiseconds:02d}"
+
             start_timestamp = self._get_start_timestamp_str(stream_info)
 
             # --- Alert settings and alerts for each metric ---
@@ -235,21 +295,36 @@ class AdvancedCustomerServiceUseCase(BaseProcessor):
                 "reset_settings": reset_settings,
                 "human_text": human_text
             }
-            business_analytics = [{
+            # Patch: Build real_time_occupancy with correct service_areas info (not just empty lists)
+            real_time_occupancy = analytics_results.get("real_time_occupancy", {}).copy()
+            # Overwrite service_areas with per-zone info matching service_areas_status
+            service_areas_status = service_analytics.get("service_areas_status", {})
+            real_time_occupancy["service_areas"] = {}
+            for area_name, area_info in service_areas_status.items():
+                real_time_occupancy["service_areas"][area_name] = {
+                    "customers": area_info.get("customers", 0),
+                    "customer_ids": area_info.get("customer_ids", []),
+                    "staff": area_info.get("staff", 0),
+                    "staff_ids": area_info.get("staff_ids", []),
+                    "service_ratio": area_info.get("service_ratio", 0.0),
+                    "status": area_info.get("status", "inactive"),
+                    "service_proximity_threshold": area_info.get("service_proximity_threshold", 230)
+                }
+            business_analytics = {
                 "business_metrics": business_metrics,
                 "customer_queue_analytics": queue_analytics,
                 "staff_management_analytics": staff_analytics,
                 "service_area_analytics": service_analytics,
                 "customer_journey_analytics": journey_analytics,
                 "service_times": analytics_results.get("service_times", []),
-                "real_time_occupancy": analytics_results.get("real_time_occupancy", {}),
+                "real_time_occupancy": real_time_occupancy,
                 "alerts": alerts,
                 "alert_settings": alert_settings
-            }]
+            }
 
             agg_summary[str(frame_id)] = {
-                "incidents": [event],
-                "tracking_stats": [tracking_stat],
+                "incidents": event,
+                "tracking_stats": tracking_stat,
                 "business_analytics": business_analytics,
                 "alerts": alerts,
                 "human_text": human_text
