@@ -1,5 +1,5 @@
 from typing import Any, Dict, List, Optional
-from dataclasses import asdict
+from dataclasses import asdict, dataclass, field
 import time
 from datetime import datetime, timezone
 
@@ -16,12 +16,11 @@ from ..utils import (
     BBoxSmoothingConfig,
     BBoxSmoothingTracker
 )
-from dataclasses import dataclass, field
 from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class VehicleMonitoringConfig(BaseConfig):
-    """Configuration for vehicle detection use case."""
+    """Configuration for vehicle monitoring use case."""
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"
     smoothing_window_size: int = 20
@@ -132,7 +131,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             self.logger.debug(f"Applied confidence filtering with threshold {config.confidence_threshold}")
         else:
             processed_data = data
-            self.logger.debug("Did not apply confidence filtering since no threshold provided")
+            self.logger.debug("Did not apply confidence filtering")
 
         if config.index_to_category:
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
@@ -228,6 +227,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
         alerts = []
         total_detections = summary.get("total_count", 0)
         total_counts_dict = summary.get("total_counts", {})
+        cumulative_total = sum(total_counts_dict.values()) if total_counts_dict else 0
         per_category_count = summary.get("per_category_count", {})
 
         if not config.alert_config:
@@ -237,37 +237,36 @@ class VehicleMonitoringUseCase(BaseProcessor):
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category == "all" and total_detections > threshold:
                     alerts.append({
-                        "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
+                        "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                         "alert_id": f"alert_{category}_{frame_key}",
                         "incident_category": self.CASE_TYPE,
                         "threshold_level": threshold,
                         "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
-                        "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
-                                                        getattr(config.alert_config, 'alert_value', ['JSON']))}
+                        "settings": {t: v for t, v in zip(
+                            getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                            getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])}
+                    })
+                elif category in per_category_count and per_category_count[category] > threshold:
+                    alerts.append({
+                        "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                        "alert_id": f"alert_{category}_{frame_key}",
+                        "incident_category": self.CASE_TYPE,
+                        "threshold_level": threshold,
+                        "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
+                        "settings": {t: v for t, v in zip(
+                            getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                            getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])}
                     })
-                elif category in per_category_count:
-                    count = per_category_count[category]
-                    if count > threshold:
-                        alerts.append({
-                            "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
-                            "alert_id": f"alert_{category}_{frame_key}",
-                            "incident_category": self.CASE_TYPE,
-                            "threshold_level": threshold,
-                            "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
-                            "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
-                                                            getattr(config.alert_config, 'alert_value', ['JSON']))}
-                        })
         return alerts
 
     def _generate_incidents(self, counting_summary: Dict, alerts: List, config: VehicleMonitoringConfig,
-                         frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
+                           frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
         incidents = []
         total_detections = counting_summary.get("total_count", 0)
         current_timestamp = self._get_current_timestamp_str(stream_info)
         camera_info = self.get_camera_info_from_stream(stream_info)
-        
         self._ascending_alert_list = self._ascending_alert_list[-900:] if len(self._ascending_alert_list) > 900 else self._ascending_alert_list
-        
+
         if total_detections > 0:
             level = "low"
             intensity = 5.0
@@ -279,7 +278,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
                     self.current_incident_end_timestamp = current_timestamp
             elif self.current_incident_end_timestamp != 'Incident still active' and self.current_incident_end_timestamp != 'N/A':
                 self.current_incident_end_timestamp = 'N/A'
-                
+
             if config.alert_config and config.alert_config.count_thresholds:
                 threshold = config.alert_config.count_thresholds.get("all", 15)
                 intensity = min(10.0, (total_detections / threshold) * 10)
@@ -320,12 +319,13 @@ class VehicleMonitoringUseCase(BaseProcessor):
             alert_settings = []
             if config.alert_config and hasattr(config.alert_config, 'alert_type'):
                 alert_settings.append({
-                    "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
+                    "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                     "incident_category": self.CASE_TYPE,
                     "threshold_level": config.alert_config.count_thresholds if hasattr(config.alert_config, 'count_thresholds') else {},
                     "ascending": True,
-                    "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
-                                                    getattr(config.alert_config, 'alert_value', ['JSON']))}
+                    "settings": {t: v for t, v in zip(
+                        getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                        getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])}
                 })
 
             event = self.create_incident(
@@ -365,12 +365,9 @@ class VehicleMonitoringUseCase(BaseProcessor):
         for detection in counting_summary.get("detections", []):
             bbox = detection.get("bounding_box", {})
             category = detection.get("category", "vehicle")
-            if detection.get("masks"):
-                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("masks"))
-            elif detection.get("segmentation"):
-                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("segmentation"))
-            elif detection.get("mask"):
-                detection_obj = self.create_detection_object(category, bbox, segmentation=detection.get("mask"))
+            if detection.get("masks") or detection.get("segmentation") or detection.get("mask"):
+                segmentation = detection.get("masks") or detection.get("segmentation") or detection.get("mask")
+                detection_obj = self.create_detection_object(category, bbox, segmentation=segmentation)
             else:
                 detection_obj = self.create_detection_object(category, bbox)
             detections.append(detection_obj)
@@ -378,27 +375,24 @@ class VehicleMonitoringUseCase(BaseProcessor):
         alert_settings = []
         if config.alert_config and hasattr(config.alert_config, 'alert_type'):
             alert_settings.append({
-                "alert_type": getattr(config.alert_config, 'alert_type', ['Default']),
+                "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                 "incident_category": self.CASE_TYPE,
                 "threshold_level": config.alert_config.count_thresholds if hasattr(config.alert_config, 'count_thresholds') else {},
                 "ascending": True,
-                "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
-                                                getattr(config.alert_config, 'alert_value', ['JSON']))}
+                "settings": {t: v for t, v in zip(
+                    getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
+                    getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])}
             })
 
         human_text_lines = [f"Tracking Statistics:"]
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}")
         for cat, count in per_category_count.items():
-            human_text_lines.append(f"\t{self.CATEGORY_DISPLAY.get(cat, cat)}: {count}")
+            human_text_lines.append(f"\t{cat}: {count}")
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}")
         for cat, count in total_counts_dict.items():
             if count > 0:
-                human_text_lines.append(f"\t{self.CATEGORY_DISPLAY.get(cat, cat)}: {count}")
-        if alerts:
-            for alert in alerts:
-                human_text_lines.append(f"Alerts: {alert.get('settings', {})} sent @ {current_timestamp}")
-        else:
-            human_text_lines.append("Alerts: None")
+                human_text_lines.append(f"\t{cat}: {count}")
+        human_text_lines.append("Alerts: None" if not alerts else f"Alerts: {alerts[0].get('settings', {})} sent @ {current_timestamp}")
         human_text = "\n".join(human_text_lines)
 
         reset_settings = [{"interval_type": "daily", "reset_time": {"value": 9, "time_unit": "hour"}}]
@@ -422,8 +416,6 @@ class VehicleMonitoringUseCase(BaseProcessor):
                                     is_empty=False) -> List[Dict]:
         if is_empty:
             return []
-        # Implement business analytics if needed
-        return []
 
     def _generate_summary(self, summary: dict, incidents: List, tracking_stats: List, business_analytics: List, alerts: List) -> List[str]:
         lines = {}
@@ -440,11 +432,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
         return [lines]
 
     def _get_track_ids_info(self, detections: list) -> Dict[str, Any]:
-        frame_track_ids = set()
-        for det in detections:
-            tid = det.get('track_id')
-            if tid is not None:
-                frame_track_ids.add(tid)
+        frame_track_ids = {det.get('track_id') for det in detections if det.get('track_id') is not None}
         total_track_ids = set()
         for s in getattr(self, '_per_category_total_track_ids', {}).values():
             total_track_ids.update(s)
